Module logger

Module logger 

This file contains wrapper macros for the env_logger crate. I specifically wanted to wrap around warn as I wanted all warnings to panic if they occurred in the Github Actions workflow.