Module error

Module error 

Enums

DateError
Represents different types of Date errors.
ParserError
Represents possible issues that may arise when trying to parse web feeds. If this occurs then a web feed is considered invalid.